;; Generated package description from dmsg.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "dmsg" "0.3.0.20260513.113120" "Timestamped debug messages with backtrace support" '((emacs "28.1")) :commit "b5c383e931499f9e3693833a2863e019429c3f7b" :authors '(("Al Haji-Ali" . "abdo.haji.ali@gmail.com")) :maintainer '("Al Haji-Ali" . "abdo.haji.ali@gmail.com") :keywords '("maint" "tools") :url "https://github.com/haji-ali/dmsg.el")
